import { SESSION_PASSWORD, readJson, writeJson } from "../../utils"
import { getAvailableNodePort, getUserAllConfigs, getUserConfig } from "../../utils/server"

export default defineEventHandler(async (event) => {
  try {
    const body = await readBody(event)
    const username = body.username
    // 当用户数据文件没有 node-port 时，认为该用户还没有注册过
    if (getUserConfig(username, 'node-port') === undefined) {
      let host = process.env.NODE_ENV?.trim() === 'production' ? '192.168.0.4' : 'localhost'
      const port = await getAvailableNodePort(host)
      const userDefaultSetting = readJson('./server/files/default-user-setting.json')
      const userSetting = Object.assign({}, userDefaultSetting, { "node-port": port })
      userSetting['postgres']['database'] = username
      userSetting['tenants']['id'] = username
      userSetting['tenants']['host'] = `a.test.com:${23333+ (port - 30000)*2},a.test.com:${23334+(port-30000)*2}`
      userSetting.username = username
      const userDataPath = `./server/data/${username}.json`
      writeJson(userDataPath, userSetting)
    }
    const session = await useSession(event, { password: SESSION_PASSWORD })
    await session.update({ username })
    return session.data
  } catch (err) {
    console.log(err)
    throw createError({
      statusCode: 500,
      statusMessage: '登录失败'
    })
  }
})